/*
** Generated by X-Designer
*/
#ifndef _popups12_h
#define _popups12_h

#define XD_MOTIF



extern Widget shell;
extern Widget form;
extern Widget drawingArea1;
extern Widget menuA;
extern Widget menuB;

extern void create_menuA (Widget);
extern void create_menuB (Widget);
extern void create_shell (Display *, char *, int, char **);



#endif
